@@ -27,7 +27,7 @@ public:
     DlgWebinterface(QDialog *parent = nullptr);
     ~DlgWebinterface() override;
     
-signals:
+Q_SIGNALS:
     void changed();
     void saved();
 
@@ -37,7 +37,7 @@ private Q_SLOTS:
     void walletOpened(bool);
     
 private:
-    KWallet::Wallet *m_wallet;
+    KWallet::Wallet *m_wallet = nullptr;
 };
 
 #endif
